camelot.camelot.view.controls.delegates.CodeColumnDelegate

Package camelot :: Package camelot :: Package view :: Package controls :: Module delegates :: Class CodeColumnDelegate |
[hide private]
[frames] | no frames]

# Class CodeColumnDelegate

source code

Instance Methods | [hide private]
__init__(self, parts, parent=None) | source code
createEditor(self, parent, option, index) | source code
commitAndCloseEditor(self) | source code
setEditorData(self, editor, index) | source code
sizeHint(self, option, index) | source code
setModelData(self, editor, model, index) | source code